@@ -5,15 +5,16 @@
  */
 
 #include "Rating.h"
-#include <QStringList>
 #include "libdiscover_debug.h"
+#include <QStringList>
 #include <qmath.h>
 
-inline double fastPow(double a, double b) {
+inline double fastPow(double a, double b)
+{
     union {
         double d;
         int x[2];
-    } u = { a };
+    } u = {a};
 
 #if Q_BYTE_ORDER == Q_LITTLE_ENDIAN
     u.x[1] = (int)(b * (u.x[1] - 1072632447) + 1072632447);
@@ -29,26 +30,36 @@ inline double fastPow(double a, double b) {
 // Converted from a Ruby example, returns an inverse normal distribution
 double pnormaldist(double qn)
 {
-    double b[] = {1.570796288, 0.03706987906, -0.8364353589e-3, -0.2250947176e-3, 0.6841218299e-5, 0.5824238515e-5, -0.104527497e-5, 0.8360937017e-7, -0.3231081277e-8, 0.3657763036e-10, 0.6936233982e-12};
+    double b[] = {1.570796288,
+                  0.03706987906,
+                  -0.8364353589e-3,
+                  -0.2250947176e-3,
+                  0.6841218299e-5,
+                  0.5824238515e-5,
+                  -0.104527497e-5,
+                  0.8360937017e-7,
+                  -0.3231081277e-8,
+                  0.3657763036e-10,
+                  0.6936233982e-12};
 
-    if(qn < 0.0 || 1.0 < qn)
+    if (qn < 0.0 || 1.0 < qn)
         return 0.0;
 
-    if(qn == 0.5)
+    if (qn == 0.5)
         return 0.0;
 
     double w1 = qn;
-    if(qn > 0.5)
+    if (qn > 0.5)
         w1 = 1.0 - w1;
     double w3 = -qLn(4.0 * w1 * (1.0 - w1));
     w1 = b[0];
 
-    for(int i = 1; i < 11; i++)
-        w1 += b[i] * fastPow(w3,i);
+    for (int i = 1; i < 11; i++)
+        w1 += b[i] * fastPow(w3, i);
 
-    if(qn > 0.5)
-        return qSqrt(w1*w3);
-    return -qSqrt(w1*w3);
+    if (qn > 0.5)
+        return qSqrt(w1 * w3);
+    return -qSqrt(w1 * w3);
 }
 
 double wilson_score(int pos, int n, double power = 0.2)
@@ -58,8 +69,7 @@ double wilson_score(int pos, int n, double power = 0.2)
 
     double z = pnormaldist(1 - power / 2);
     double phat = 1.0 * pos / n;
-    return (phat + z * z / (2 * n) - z * qSqrt(
-            (phat * (1 - phat) + z * z / (4 * n)) / n)) / (1 + z * z / n);
+    return (phat + z * z / (2 * n) - z * qSqrt((phat * (1 - phat) + z * z / (4 * n)) / n)) / (1 + z * z / n);
 }
 
 double dampenedRating(int ratings[6], double power = 0.1)
@@ -82,16 +92,20 @@ Rating::Rating(const QString &packageName, quint64 ratingCount, int data[6])
     : m_packageName(packageName)
     , m_ratingCount(ratingCount)
     // TODO consider storing data[] and present in UI
-    , m_rating(((data[1] + (data[2] * 2) +
-                (data[3] * 3) + (data[4] * 4) +
-                (data[5] * 5)) * 2) / qMax<float>(1, ratingCount))
+    , m_rating(((data[1] //
+                 + (data[2] * 2) //
+                 + (data[3] * 3) //
+                 + (data[4] * 4) //
+                 + (data[5] * 5)) //
+                * 2)
+               / qMax<float>(1, ratingCount))
     , m_ratingPoints(0)
     , m_sortableRating(0)
 {
     int spread[6];
-    for(int i=0; i<6; ++i) {
+    for (int i = 0; i < 6; ++i) {
         int points = data[i];
-        m_ratingPoints += (i+1)*points;
+        m_ratingPoints += (i + 1) * points;
         spread[i] = points;
     }
 
@@ -133,3 +147,5 @@ double Rating::sortableRating() const
 {
     return m_sortableRating;
 }
+
+#include "moc_Rating.cpp"
